import request from './request'

export function getOrderList() {
  return request.get('/order/list')
}

export function cancelOrder(id: number) {
  return request.post('/order/cancel', { id })
}

export function deleteOrder(id: number) {
  return request.post('/order/delete', { id })
}

export function getOrderInfo(id: number) {
  return request.get('/order/info?id=' + id)
}

/** 礼品寄送-填写邮寄地址 */
export function applyPost(data: any) {
  return request.post('/order/post/apply', data)
}

export function getPostInfo(member_right_id: string) {
  return request.get('/order/post/info', { params: { member_right_id } })
}

/**
 * 我的礼品卡
 * @param status 状态：0未使用；1已使用；2已失效
 */
export function getGiftCardList(status: 0 | 1 | 2) {
  return request.get('/gift-card/list', { params: { status } }).then(res => {
    res.results.items.forEach((item: any) => {
      const threshold = item.gift_card_threshold
      item.gift_card_threshold = threshold ? +threshold : 0
    })
    return res
  })
}

export function getProductList() {
  return request.get('/product/list')
}

/** 校验优惠码 */
export function checkDiscount(code: string) {
  return request.post('/product/discount/check', { code })
}

export function getBrands() {
  return request.get('/igeektek?api=v2/brands')
}

export function getModels(brand_id: string) {
  return request.get('/igeektek?api=v2/phones', {
    params: {
      brand_id,
      per_page: 1000,
      igeektek_id: '',
      from: 'PC',
    },
  })
}

/** 提交订单 */
export function checkoutOrder(data: any) {
  return request.post('/order/checkout', data)
}

export function bindIMEI(data: { id: number; imei: string }) {
  return request.post('/order/bindIMEI', data)
}

export function unsubscribe(id: number) {
  return request.post('/order/unSubscribe', { id })
}
